==> jc-1.4.0.tar.gz: gnu/java/awt/color/RgbProfileConverter.h <==
// public class gnu.java.awt.color.RgbProfileConverter

// class file dependencies
// @dep_class d2a8c94974dbf296 gnu_java_awt_color_RgbProfileConverter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_color_RgbProfileConverter_H_
#define _JC_gnu_java_awt_color_RgbProfileConverter_H_

// Forward structure declarations
struct _jc_gnu_java_awt_color_ColorLookUpTable$object;
struct _jc_gnu_java_awt_color_ToneReproductionCurve$object;
struct _jc_java_awt_color_ICC__5fProfileRGB$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_color_RgbProfileConverter$sub_refs	_jc_gnu_java_awt_color_RgbProfileConverter$sub_refs;
typedef struct _jc_gnu_java_awt_color_RgbProfileConverter$sub_nonrefs	_jc_gnu_java_awt_color_RgbProfileConverter$sub_nonrefs;
typedef struct _jc_gnu_java_awt_color_RgbProfileConverter$refs	_jc_gnu_java_awt_color_RgbProfileConverter$refs;
typedef struct _jc_gnu_java_awt_color_RgbProfileConverter$nonrefs	_jc_gnu_java_awt_color_RgbProfileConverter$nonrefs;
typedef struct _jc_gnu_java_awt_color_RgbProfileConverter$object	_jc_gnu_java_awt_color_RgbProfileConverter$object;

typedef struct _jc_gnu_java_awt_color_RgbProfileConverter$fields_struct	_jc_gnu_java_awt_color_RgbProfileConverter$fields_struct;
typedef const struct _jc_gnu_java_awt_color_RgbProfileConverter$vmethods	_jc_gnu_java_awt_color_RgbProfileConverter$vmethods;
typedef const struct _jc_gnu_java_awt_color_RgbProfileConverter$vtable	_jc_gnu_java_awt_color_RgbProfileConverter$vtable;
typedef const struct _jc_gnu_java_awt_color_RgbProfileConverter$vtype	_jc_gnu_java_awt_color_RgbProfileConverter$vtype;

// Class fields structure
struct _jc_gnu_java_awt_color_RgbProfileConverter$fields_struct {
	_jc_float_array	*D50;
};
extern _jc_gnu_java_awt_color_RgbProfileConverter$fields_struct _jc_gnu_java_awt_color_RgbProfileConverter$class_fields;

// Constructors
extern void _jc_gnu_java_awt_color_RgbProfileConverter$method$_init$ec121c6a927dee72(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *);

// Virtual methods
extern _jc_float_array *_jc_gnu_java_awt_color_RgbProfileConverter$method$fromCIEXYZ$7b319ba108c72c43(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_float_array *);
extern _jc_float_array *_jc_gnu_java_awt_color_RgbProfileConverter$method$fromRGB$241337c328fb6c81(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_float_array *);
extern _jc_object_array *_jc_gnu_java_awt_color_RgbProfileConverter$method$invertMatrix$f4121eab7b30bd91(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_object_array *);
extern _jc_float_array *_jc_gnu_java_awt_color_RgbProfileConverter$method$toCIEXYZ$ea146856208217b9(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_float_array *);
extern _jc_float_array *_jc_gnu_java_awt_color_RgbProfileConverter$method$toRGB$8e7372c09e81aa9c(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_float_array *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_color_RgbProfileConverter$method_info$fromCIEXYZ$7b319ba108c72c43;
extern _jc_method _jc_gnu_java_awt_color_RgbProfileConverter$method_info$fromRGB$241337c328fb6c81;
extern _jc_method _jc_gnu_java_awt_color_RgbProfileConverter$method_info$invertMatrix$f4121eab7b30bd91;
extern _jc_method _jc_gnu_java_awt_color_RgbProfileConverter$method_info$toCIEXYZ$ea146856208217b9;
extern _jc_method _jc_gnu_java_awt_color_RgbProfileConverter$method_info$toRGB$8e7372c09e81aa9c;

// Static methods
extern void _jc_gnu_java_awt_color_RgbProfileConverter$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_awt_color_RgbProfileConverter$vmethods {
	_jc_float_array	*(*fromCIEXYZ$7b319ba108c72c43)(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_float_array *);
	_jc_float_array	*(*fromRGB$241337c328fb6c81)(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_float_array *);
	_jc_object_array	*(*invertMatrix$f4121eab7b30bd91)(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_object_array *);
	_jc_float_array	*(*toCIEXYZ$ea146856208217b9)(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_float_array *);
	_jc_float_array	*(*toRGB$8e7372c09e81aa9c)(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_float_array *);
};

// Vtable
struct _jc_gnu_java_awt_color_RgbProfileConverter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_color_RgbProfileConverter$vmethods	gnu_java_awt_color_RgbProfileConverter;
};

// Vtype
struct _jc_gnu_java_awt_color_RgbProfileConverter$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_color_RgbProfileConverter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_color_RgbProfileConverter$sub_refs {
	_jc_object_array	*matrix;
	_jc_object_array	*inv__5fmatrix;
	struct _jc_gnu_java_awt_color_ToneReproductionCurve$object	*rTRC;
	struct _jc_gnu_java_awt_color_ToneReproductionCurve$object	*gTRC;
	struct _jc_gnu_java_awt_color_ToneReproductionCurve$object	*bTRC;
	struct _jc_gnu_java_awt_color_ColorLookUpTable$object	*toPCS;
	struct _jc_gnu_java_awt_color_ColorLookUpTable$object	*fromPCS;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_color_RgbProfileConverter$refs {
    _jc_gnu_java_awt_color_RgbProfileConverter$sub_refs	gnu_java_awt_color_RgbProfileConverter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_color_RgbProfileConverter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_color_RgbProfileConverter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_color_RgbProfileConverter$sub_nonrefs	gnu_java_awt_color_RgbProfileConverter;
};

// Object instance structure
struct _jc_gnu_java_awt_color_RgbProfileConverter$object {
	_jc_gnu_java_awt_color_RgbProfileConverter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_color_RgbProfileConverter$vtype	*vtype;
	_jc_gnu_java_awt_color_RgbProfileConverter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_color_RgbProfileConverter$vtype _jc_gnu_java_awt_color_RgbProfileConverter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_color_RgbProfileConverter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_color_RgbProfileConverter$class_object;

#endif	/* _JC_gnu_java_awt_color_RgbProfileConverter_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/color/RgbProfileConverter.h <==
// public class gnu.java.awt.color.RgbProfileConverter

// class file dependencies
// @dep_class 7383ff64742d2d8f gnu_java_awt_color_RgbProfileConverter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_color_RgbProfileConverter_H_
#define _JC_gnu_java_awt_color_RgbProfileConverter_H_

// Forward structure declarations
struct _jc_gnu_java_awt_color_ColorLookUpTable$object;
struct _jc_gnu_java_awt_color_ToneReproductionCurve$object;
struct _jc_java_awt_color_ICC__5fProfileRGB$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_color_RgbProfileConverter$sub_refs	_jc_gnu_java_awt_color_RgbProfileConverter$sub_refs;
typedef struct _jc_gnu_java_awt_color_RgbProfileConverter$sub_nonrefs	_jc_gnu_java_awt_color_RgbProfileConverter$sub_nonrefs;
typedef struct _jc_gnu_java_awt_color_RgbProfileConverter$refs	_jc_gnu_java_awt_color_RgbProfileConverter$refs;
typedef struct _jc_gnu_java_awt_color_RgbProfileConverter$nonrefs	_jc_gnu_java_awt_color_RgbProfileConverter$nonrefs;
typedef struct _jc_gnu_java_awt_color_RgbProfileConverter$object	_jc_gnu_java_awt_color_RgbProfileConverter$object;

typedef struct _jc_gnu_java_awt_color_RgbProfileConverter$fields_struct	_jc_gnu_java_awt_color_RgbProfileConverter$fields_struct;
typedef const struct _jc_gnu_java_awt_color_RgbProfileConverter$vmethods	_jc_gnu_java_awt_color_RgbProfileConverter$vmethods;
typedef const struct _jc_gnu_java_awt_color_RgbProfileConverter$vtable	_jc_gnu_java_awt_color_RgbProfileConverter$vtable;
typedef const struct _jc_gnu_java_awt_color_RgbProfileConverter$vtype	_jc_gnu_java_awt_color_RgbProfileConverter$vtype;

// Class fields structure
struct _jc_gnu_java_awt_color_RgbProfileConverter$fields_struct {
	_jc_float_array	*D50;
};
extern _jc_gnu_java_awt_color_RgbProfileConverter$fields_struct _jc_gnu_java_awt_color_RgbProfileConverter$class_fields;

// Constructors
extern void _jc_gnu_java_awt_color_RgbProfileConverter$method$_init$ec121c6a927dee72(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_float_array *_jc_gnu_java_awt_color_RgbProfileConverter$method$fromCIEXYZ$7b319ba108c72c43(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_gnu_java_awt_color_RgbProfileConverter$method$fromRGB$241337c328fb6c81(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_gnu_java_awt_color_RgbProfileConverter$method$invertMatrix$f4121eab7b30bd91(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_gnu_java_awt_color_RgbProfileConverter$method$toCIEXYZ$ea146856208217b9(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_gnu_java_awt_color_RgbProfileConverter$method$toRGB$8e7372c09e81aa9c(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_color_RgbProfileConverter$method_info$fromCIEXYZ$7b319ba108c72c43;
extern _jc_method _jc_gnu_java_awt_color_RgbProfileConverter$method_info$fromRGB$241337c328fb6c81;
extern _jc_method _jc_gnu_java_awt_color_RgbProfileConverter$method_info$invertMatrix$f4121eab7b30bd91;
extern _jc_method _jc_gnu_java_awt_color_RgbProfileConverter$method_info$toCIEXYZ$ea146856208217b9;
extern _jc_method _jc_gnu_java_awt_color_RgbProfileConverter$method_info$toRGB$8e7372c09e81aa9c;

// Static methods
extern void _jc_gnu_java_awt_color_RgbProfileConverter$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_awt_color_RgbProfileConverter$vmethods {
	_jc_float_array	*(*fromCIEXYZ$7b319ba108c72c43)(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	_jc_float_array	*(*fromRGB$241337c328fb6c81)(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	_jc_object_array	*(*invertMatrix$f4121eab7b30bd91)(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
	_jc_float_array	*(*toCIEXYZ$ea146856208217b9)(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	_jc_float_array	*(*toRGB$8e7372c09e81aa9c)(_jc_env *, struct _jc_gnu_java_awt_color_RgbProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_color_RgbProfileConverter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_color_RgbProfileConverter$vmethods	gnu_java_awt_color_RgbProfileConverter;
};

// Vtype
struct _jc_gnu_java_awt_color_RgbProfileConverter$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_color_RgbProfileConverter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_color_RgbProfileConverter$sub_refs {
	_jc_object_array	*matrix;
	_jc_object_array	*inv__5fmatrix;
	struct _jc_gnu_java_awt_color_ToneReproductionCurve$object	*rTRC;
	struct _jc_gnu_java_awt_color_ToneReproductionCurve$object	*gTRC;
	struct _jc_gnu_java_awt_color_ToneReproductionCurve$object	*bTRC;
	struct _jc_gnu_java_awt_color_ColorLookUpTable$object	*toPCS;
	struct _jc_gnu_java_awt_color_ColorLookUpTable$object	*fromPCS;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_color_RgbProfileConverter$refs {
    _jc_gnu_java_awt_color_RgbProfileConverter$sub_refs	gnu_java_awt_color_RgbProfileConverter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_color_RgbProfileConverter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_color_RgbProfileConverter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_color_RgbProfileConverter$sub_nonrefs	gnu_java_awt_color_RgbProfileConverter;
};

// Object instance structure
struct _jc_gnu_java_awt_color_RgbProfileConverter$object {
	_jc_gnu_java_awt_color_RgbProfileConverter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_color_RgbProfileConverter$vtype	*vtype;
	_jc_gnu_java_awt_color_RgbProfileConverter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_color_RgbProfileConverter$vtype _jc_gnu_java_awt_color_RgbProfileConverter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_color_RgbProfileConverter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_color_RgbProfileConverter$class_object;

#endif	/* _JC_gnu_java_awt_color_RgbProfileConverter_H_ */
